@@ -168,15 +168,31 @@ ForkedBlockchain.prototype.initialize = async function(accounts, callback) {
   try {
     const forkVersion = await new Promise((resolve, reject) => {
       this.web3.eth.net.getId((err, version) => {
-        err ? reject(err) : resolve(version);
+        if (err) {
+          Error.captureStackTrace(err);
+          err.message = `The fork provider errored when checking net_version: ${err.message}`;
+          reject(err);
+        } else {
+          resolve(version);
+        }
       });
     });
 
     this.forkVersion = forkVersion;
 
     const forkBlock = (this.forkBlock = await new Promise((resolve, reject) => {
-      this.web3.eth.getBlock(this.forkBlockNumber || "latest", (err, json) => {
-        err ? reject(err) : resolve(json);
+      const queriedBlock = this.forkBlockNumber || "latest";
+      this.web3.eth.getBlock(queriedBlock, (err, json) => {
+        if (err) {
+          Error.captureStackTrace(err);
+          err.message =
+            `The fork provider errored when checking for block '${
+              queriedBlock
+            }': ${err.message}`;
+          reject(err);
+        } else {
+          resolve(json);
+        }
       });
     }));
 
@@ -197,7 +213,16 @@ ForkedBlockchain.prototype.initialize = async function(accounts, callback) {
       accounts.map((account) => {
         return new Promise((resolve, reject) => {
           this.web3.eth.getTransactionCount(account.address, this.forkBlockNumber, (err, nonce) => {
-            err ? reject(err) : resolve(nonce);
+            if (err) {
+              Error.captureStackTrace(err);
+              err.message =
+                `The fork provider errored when checking the nonce for account ${
+                  account.address
+                }: ${err.message}`;
+              reject(err);
+            } else {
+              resolve(nonce);
+            }
           });
         });
       })
@@ -820,4 +845,11 @@ ForkedBlockchain.prototype.getBlockLogs = function(number, callback) {
   });
 };
 
+ForkedBlockchain.prototype.close = function(callback) {
+  if (this.fork.disconnect) {
+    this.fork.disconnect();
+  }
+  BlockchainDouble.prototype.close.call(this, callback);
+};
+
 module.exports = ForkedBlockchain;
