@@ -149,7 +149,7 @@ GethApiDouble.prototype.eth_blockNumber = function(callback) {
 };
 
 GethApiDouble.prototype.eth_chainId = function(callback) {
-  callback(null, to.hex(1337));
+  callback(null, to.hex(this.options._chainIdRpc));
 };
 
 GethApiDouble.prototype.eth_coinbase = function(callback) {
@@ -565,6 +565,65 @@ GethApiDouble.prototype.evm_mine = function(timestamp, callback) {
 // indicate that `evm_mine` only requires one argument (the callback)
 GethApiDouble.prototype.evm_mine.minLength = 1;
 
+/**
+ * Unlocks any unknown account.
+ *
+ * Note: accounts known to the `personal` namespace and accounts returned by
+ * `eth_accounts` cannot be unlocked using this method.
+ *
+ * @param {*} address the address of the account to unlock
+ * @param {*} callback
+ * @returns `true` if the account was unlocked successfully, `false` if the
+ * account was already unlocked. Throws an error if the account could not be
+ * unlocked.
+ */
+GethApiDouble.prototype.evm_unlockUnknownAccount = function(address, callback) {
+  // check if given address is already unlocked
+  address = address.toLowerCase();
+  if (this.state.unlocked_accounts[address] !== true) {
+    if (this.state.personal_accounts[address] !== true) {
+      // unlock the account
+      this.state.unlocked_accounts[address] = true;
+      return callback(null, true);
+    } else {
+      // if the account is known to the `personal` namespace we may not unlock
+      // it
+      return callback(new Error("cannot unlock known/personal account"));
+    }
+  }
+  // account was already unlocked, return `false`
+  callback(null, false);
+};
+
+/**
+ * Locks any unknown account.
+ *
+ * Note: accounts known to the `personal` namespace and accounts returned by
+ * `eth_accounts` cannot be locked using this method.
+ *
+ * @param {*} address the address of the account to lock
+ * @param {*} callback
+ * @returns `true` if the account was locked successfully, `false` if the
+ * account was already locked. Throws an error if the account could not be
+ * locked.
+ */
+GethApiDouble.prototype.evm_lockUnknownAccount = function(address, callback) {
+  // Checks if given address is already unlocked
+  address = address.toLowerCase();
+  if (this.state.unlocked_accounts[address]) {
+    if (this.state.personal_accounts[address]) {
+      // if the account is known to the `personal` namespace we may not lock it
+      return callback(new Error("cannot lock known/personal account"));
+    } else {
+      // unlock the account
+      delete this.state.unlocked_accounts[address];
+      return callback(null, true);
+    }
+  }
+  // account wasn't locked to begin with, return `false`
+  callback(null, false);
+};
+
 GethApiDouble.prototype.debug_traceTransaction = function(txHash, params, callback) {
   if (typeof params === "function") {
     callback = params;
